@@ -149,11 +149,25 @@ class FormatTests(LoggingTestCase):
             return
         ah = logging.getLogger('').addHandler
         ah(logging.handlers.TimedRotatingFileHandler('/bar/two.txt'))
-        self.assertEqual(build_description(), '''\
+        expected = '''\
 <--""
    Level WARNING
    Handler TimedRotatingFile '/bar/two.txt' when='H' interval=3600 backupCount=0
-''')
+'''
+        if sys.version_info >= (3, 8):
+            # Apparently the design of the TimedRotatingFileHandler has
+            # become a bit more ambitious as of Python 3.8.
+            expected += '''\
+   |
+   o<--"asyncio"
+   |   Level NOTSET so inherits level WARNING
+   |
+   o<--[concurrent]
+       |
+       o<--"concurrent.futures"
+           Level NOTSET so inherits level WARNING
+'''
+        self.assertEqual(build_description(), expected)
 
     def test_2_dot_6_handlers(self):
         if sys.version_info < (2, 6):
